@@ -12,7 +12,11 @@ from ..errors import SubmitError
 
 
 class JobStatus(enum.IntEnum):
-    """Classifies the job's execution status."""
+    """Classifies the job's execution status.
+
+    Group statuses exist to enable status output for individual operations within a
+    larger group.
+    """
 
     unknown = 1
     """Unknown cluster job status."""
@@ -45,12 +49,58 @@ class JobStatus(enum.IntEnum):
     error = 8
     """The cluster job is in an error or failed state."""
 
+    group_registered = 9
+    """The operation is in a group that is registered with the scheduler."""
+
+    group_inactive = 10
+    """The operation is in a group that is inactive.
+
+    This includes states like completed, cancelled, or timed out.
+    """
+
+    group_submitted = 11
+    """The operation is in a group that has been submitted.
+
+    Note that this state is never returned by a scheduler, but is an assumed
+    state immediately after a group containing the operation is submitted.
+    """
+
+    group_held = 12
+    """The operation is in a group that is held."""
+
+    group_queued = 13
+    """The operation is in a group that is queued."""
+
+    group_active = 14
+    """The operation is in a group that is actively running."""
+
+    group_error = 15
+    """The operation is in a group that is in an error or failed state."""
+
     placeholder = 127
     """A placeholder state that is used for status rendering when no operations are eligible."""
 
     user = 128
     """All user-defined states must be >=128 in value."""
 
+    @classmethod
+    def _to_group(cls, status):
+        """Convert to an operation within a group status."""
+        try:
+            return cls(
+                {
+                    JobStatus.registered: JobStatus.group_registered,
+                    JobStatus.submitted: JobStatus.group_submitted,
+                    JobStatus.inactive: JobStatus.group_inactive,
+                    JobStatus.held: JobStatus.group_held,
+                    JobStatus.queued: JobStatus.group_queued,
+                    JobStatus.active: JobStatus.group_active,
+                    JobStatus.error: JobStatus.group_error,
+                }[status]
+            )
+        except KeyError:
+            raise ValueError(f"No equivalent group status for {status}.")
+
 
 class ClusterJob:
     """Class representing a cluster job."""
